@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="pt">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt">
 <context>
     <name>ConkyCustomizeDialog</name>
     <message>
@@ -750,7 +748,7 @@ Insira um nome para fazer a cópia.</translation>
     <message>
         <location filename="../src/mainwindow.cpp" line="447"/>
         <location filename="../src/mainwindow.cpp" line="625"/>
-        <source>A conky with the name &apos;%1&apos; already exists in your personal folder.
+        <source>A conky with the name '%1' already exists in your personal folder.
 Do you want to overwrite it?</source>
         <translation>Já existe um Conky com o nome ‘%1’ na sua pasta pessoal.
 Deseja substituí-lo?</translation>
@@ -1054,4 +1052,4 @@ Deseja personalizá-lo com as permissões de administrador?</translation>
         <translation>Cancelar</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
