@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="sv">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sv">
 <context>
     <name>ConkyCustomizeDialog</name>
     <message>
@@ -749,7 +747,7 @@ Skriv in ett namn på kopian.</translation>
     <message>
         <location filename="../src/mainwindow.cpp" line="447"/>
         <location filename="../src/mainwindow.cpp" line="625"/>
-        <source>A conky with the name &apos;%1&apos; already exists in your personal folder.
+        <source>A conky with the name '%1' already exists in your personal folder.
 Do you want to overwrite it?</source>
         <translation>En conky med namnet &apos;%1&apos; finns redan i din personliga katalog.
 Vill du skriva över den?</translation>
@@ -1053,4 +1051,4 @@ Vill du anpassa den med utökade privilegier?</translation>
         <translation>Avbryt</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
